@@ -14,7 +14,7 @@ use URI::Escape;
 
 use vars qw( $VERSION );
 
-$VERSION = '0.68';
+$VERSION = '0.69';
 
 =head1 NAME
 
@@ -1083,9 +1083,9 @@ sub show_index {
                             param     => $formatter->node_name_to_node_param($_) }
                         } sort @selnodes;
 
-    # Convert the lat+long to WGS84 as required.  If displaying a map
-    # using Leaflet, also grab the min and max lat and long.
-    my ( $min_lat, $max_lat, $min_long, $max_long );
+    # Convert the lat+long to WGS84 as required, and count how many nodes
+    # we have for the map (if using Leaflet).
+    my $nodes_on_map;
     for(my $i=0; $i<scalar @nodes;$i++) {
         my $node = $nodes[$i];
         if($node) {
@@ -1107,20 +1107,7 @@ sub show_index {
                     $node->{has_geodata} = 1;
                     $node->{wgs84_lat} = $wgs84_lat;
                     $node->{wgs84_long} = $wgs84_long;
-                    if ( !defined $min_lat ) {
-                        $min_lat = $max_lat = $wgs84_lat;
-                    } elsif ( $wgs84_lat < $min_lat ) {
-                        $min_lat = $wgs84_lat;
-                    } elsif ( $wgs84_lat > $max_lat ) {
-                        $max_lat = $wgs84_lat;
-                    }
-                    if ( !defined $min_long ) {
-                        $min_long = $max_long = $wgs84_long;
-                    } elsif ( $wgs84_long < $min_long ) {
-                        $min_long = $wgs84_long;
-                    } elsif ( $wgs84_long > $max_long ) {
-                        $max_long = $wgs84_long;
-                    }
+                    $nodes_on_map++;
                 }
             }
         }
@@ -1143,15 +1130,17 @@ sub show_index {
         } elsif ( $args{format} eq "map" ) {
             $tt_vars{display_google_maps} = 1; # override for this page
             if ( $use_leaflet ) {
-                if ( defined $min_lat ) {
-                    %tt_vars = ( %tt_vars,
-                        min_lat     => $min_lat,
-                        max_lat     => $max_lat,
-                        min_long    => $min_long,
-                        max_long    => $max_long,
-                        centre_lat  => ( ( $max_lat + $min_lat ) / 2 ),
-                        centre_long => ( ( $max_long + $min_long ) / 2 ),
-                    );
+                if ( $nodes_on_map ) {
+                    my @points = map {
+                    {  wgs84_lat =>
+                           $_->{node_data}->{metadata}->{wgs84_lat}[0],
+                      wgs84_long =>
+                           $_->{node_data}->{metadata}->{wgs84_long}[0]
+                    }
+                                     } @nodes;
+                    my %minmaxdata = OpenGuides::Utils->get_wgs84_min_max(
+                        nodes => \@points );
+                    %tt_vars = ( %tt_vars, %minmaxdata );
                 } else {
                     $tt_vars{no_nodes_on_map} = 1;
                 }
@@ -2251,12 +2240,17 @@ sub show_missing_metadata {
     my $wiki = $self->wiki;
     my $formatter = $self->wiki->formatter;
     my $script_name = $self->config->script_name;
+    my $use_leaflet = $self->config->use_leaflet;
 
-    my ($metadata_type, $metadata_value, $exclude_locales, $exclude_categories)
-        = @args{ qw( metadata_type metadata_value exclude_locales exclude_categories ) };
+    my ( $metadata_type, $metadata_value, $exclude_locales,
+         $exclude_categories, $format)
+        = @args{ qw( metadata_type metadata_value exclude_locales
+                     exclude_categories format ) };
+    $format ||= "";
 
     my @nodes;
     my $done_search = 0;
+    my $nodes_on_map;
 
     # Only search if they supplied at least a metadata type
     if($metadata_type) {
@@ -2268,45 +2262,67 @@ sub show_missing_metadata {
         );
 
         # Filter out redirects; also filter out locales/categories if required.
-        foreach my $node ( @all_nodes ) {
+        foreach my $node ( sort @all_nodes ) {
             next if ( $exclude_locales && $node =~ /^Locale / );
             next if ( $exclude_categories && $node =~ /^Category / );
-            my $content = $wiki->retrieve_node( $node );
-            next if OpenGuides::Utils->detect_redirect( content => $content );
-            push @nodes, $node;
+            my %data = $wiki->retrieve_node( $node );
+            next if OpenGuides::Utils->detect_redirect(
+                        content => $data{content} );
+            my $node_param = $formatter->node_name_to_node_param( $node );
+            my %this_node = (
+                name => $node,
+                param => $node_param,
+                address => $data{metadata}{address}[0],
+                view_url => "$script_name?$node_param",
+                edit_url => "$script_name?id=$node_param;action=edit",
+            );
+            if ( $format eq "map" && $use_leaflet ) {
+                my ( $wgs84_long, $wgs84_lat )
+                    = OpenGuides::Utils->get_wgs84_coords(
+                          latitude  => $data{metadata}{latitude}[0],
+                          longitude => $data{metadata}{longitude}[0],
+                          config    => $self->config );
+                if ( defined $wgs84_lat ) {
+                    $this_node{has_geodata} = 1;
+                    $this_node{wgs84_lat} = $wgs84_lat;
+                    $this_node{wgs84_long} = $wgs84_long;
+                    $nodes_on_map++;
+                }
+            }
+            push @nodes, \%this_node;
         }
     }
 
-    # Build nice edit etc links for our nodes
-    my @tt_nodes;
-    for my $node (@nodes) {
-        my %n;
-
-        # Make the URLs
-        my $node_param = uri_escape( $formatter->node_name_to_node_param( $node ) );
-
-        # Save into the hash
-        $n{'name'} = $node;
-        $n{'view_url'} = $script_name . "?id=" . $node_param;
-        $n{'edit_url'} = $script_name . "?id=" . $node_param . ";action=edit";
-        push @tt_nodes, \%n;
-    }
-
     # Set up our TT variables, including the search parameters
     my %tt_vars = (
                       not_editable  => 1,
                       not_deletable => 1,
                       deter_robots  => 1,
-
-                      nodes => \@tt_nodes,
+                      nodes         => \@nodes,
                       done_search    => $done_search,
+                      no_nodes_on_map => !$nodes_on_map,
                       metadata_type  => $metadata_type,
                       metadata_value => $metadata_value,
                       exclude_locales => $exclude_locales,
                       exclude_categories => $exclude_categories,
-
                       script_name => $script_name
                   );
+
+    # Figure out the map boundaries and centre, if applicable.
+    if ( $format eq "map" ) {
+        if ( $use_leaflet ) {
+            my %minmaxdata = OpenGuides::Utils->get_wgs84_min_max(
+                nodes => \@nodes );
+            if ( scalar %minmaxdata ) {
+                %tt_vars = ( %tt_vars, %minmaxdata );
+            }
+            $tt_vars{display_google_maps} = 1; # to get the JavaScript in
+        }
+        # Set the show_map var even if we don't have Leaflet enabled, so
+        # people aren't left wondering why there's no map.
+        $tt_vars{show_map} = 1;
+    }
+
     return %tt_vars if $return_tt_vars;
 
     # Render to the page
@@ -2314,6 +2330,7 @@ sub show_missing_metadata {
                                            id       => "",
                                            template => "missing_metadata.tt",
                                            tt_vars  => \%tt_vars,
+                                           noheaders => $args{noheaders} || 0,
                                         );
     return $output if $return_output;
     print $output;
